
rm(list = ls()); gc()
setwd("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/")
recipe_file <- "recipes/recipe_1_nadia_scorecards.yml"


source("modules/Loading/Loading.R")
source("modules/Calibration/Calibration.R")
source("modules/Skill/Skill.R")
source("modules/Saving/Saving.R")
source("tools/prepare_outputs.R")

recipe <- prepare_outputs(recipe_file)

for (smonth in 1:12) {
## Define recipe needed to load calibrated data and skill metrics
  recipe$Analysis$Time$sdate <- paste0(sprintf("%02d", smonth), '01')
## Load datasets
  data <- load_datasets(recipe)
## Compute skill metrics of raw data
  skill_metrics <- compute_skill_metrics(recipe, data$hcst, data$ob) 
  archive <- read_yaml(paste0(recipe$Run$code_dir, "conf/archive.yml"))$archive
  save_data(recipe, data, skill_metrics = skill_metrics)  
}


##### Script requires module Phantomjs, currently only available in Nord3 
##### Load Phantomjs in Nord3 before running script: module load Phantomjs

##### To open R in Nord·: 
#  module load R/4.1.2-foss-2019b
#  module load OpenMPI/4.0.5-GCC-8.3.0-nord3-v2
#  R


### Temporarily to be able to run without loading data first ###
setwd("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/")
library(yaml)
recipe_file <- "recipes/recipe_1_nadia_scorecards.yml"
recipe <- read_yaml(recipe_file)
archive <- read_yaml(paste0(recipe$Run$code_dir, "conf/archive.yml"))$archive
variable_dictionary <- read_yaml(paste0(recipe$Run$code_dir, "conf/variable-dictionary.yml"))$vars
type_dictionary <- read_yaml(paste0(recipe$Run$code_dir, "conf/scorecard_type.yml"))$types

input.path <- '/esarchive/scratch/nmilders/scorecards_data/input_data'
fileout <- '/esarchive/scratch/nmilders/scorecards_data/saved_results'

currentworkingdir <- getwd()

## Load configuration file 
source("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/modules/Scorecards/SC_0_configuration_functions.R")
## functions not used but libraries to be loaded


## Load data files
source("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/modules/Scorecards/SC_1_load_metrics.R")
#loaded_metrics <- SC_load_metrics(recipe)
loaded_metrics <- SC_load_metrics(system.filename = c('ecmwfs5','dwds21'),
                                  reference.filename = 'era5',
                                  var.filename = 'tas',
                                  start.year = 1993,
                                  end.year = 2016,
                                  metrics =  c('mean_bias', 'enscorr', 'rpss', 'crpss', 'enssprerr'),
                                  start.months = sprintf("%02d", 1:12),
                                  forecast.months = 1:6,
                                  input.path = '/esarchive/scratch/nmilders/scorecards_data/input_data')



## Calculate weighted mean of spatial aggregation
source("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/modules/Scorecards/SC_2_spatial_aggregation.R")
aggregated_metrics <- SC_spatial_aggregation(loaded_metrics,
                                             metrics = c('mean_bias', 'enscorr', 'rpss', 'crpss', 'enssprerr'), 
                                             # regions = list(global = c(lat.min = -90, lat.max = 90, lon.min = 0, lon.max = 360),
                                             #              europe = c(lat.min = 30, lat.max = 70, lon.min = -10, lon.max = 40)),
                                             regions = list('Tropics' = c(lon.min = 0, lon.max = 360, lat.min = -30, lat.max = 30),
                                                            'Extra-tropical NH' = c(lon.min = -0, lon.max = 360, lat.min = 30, lat.max = 90),
                                                            'Extra-tropical SH' = c(lon.min = 0, lon.max = 360, lat.min = -30, lat.max = -90)),
                                             
                                             ncores = 4)

## Transform metrics 
source("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/modules/Scorecards/SC_3_transform_data.R")
transformed_data <- SC_transform_data(aggregated_metrics, 
                                      sdate_dim = 'sdate',
                                      ftime_dim = 'time')

## Create scorecard
source("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/modules/Scorecards/SC_3_create_scorecard.R")
scorecard_table <- SC_create_table(transformed_data)

## Save scorecard
source("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/modules/Scorecards/SC_4_save_scorecard.R")
save_scorecard <- SC_save_image(system.filename, reference.filename, var.name, var.filename, period, scorecard_type)

setwd(currentworkingdir)


#################### PARAMETERS FROM RECIPE ########################

# start.year <- recipe$Analysis$Time$hcst_start ## 1993
# end.year <- recipe$Analysis$Time$hcst_end ## 2016
# 
# system.filename <- archive$System[[recipe$Analysis$Datasets$System$name]]$system_filename ## 'ecmwfs5'
# system.name <- archive$System[[recipe$Analysis$Datasets$System$name]]$system_name ## 'ECMWF System 5
# 
# reference.name <- archive$Reference[[recipe$Analysis$Datasets$Reference$name]]$reference_name ## 'ERA5'
# reference.filename <- archive$Reference[[recipe$Analysis$Datasets$Reference$name]]$reference_filename ## 'era5'
# 
# var.filename <- recipe$Analysis$Variables$name ## 'tas'
# var.name <- variable-dictionary$vars[[recipe$Analysis$Variables$name]]$long_name ##
# var.unit <- variable-dictionary$vars[[recipe$Analysis$Variables$name]]$units ## 'K'

#plevel <- '' # because single levels

