#'Function to create single system/reference scorecards
#' 
#'@description Scorecards function to create scorecard table for one system and 
#'  one reference combination.
#'@param aggregated_metrics is an array of spatially aggregated metrics loaded 
#'  in the function SC_spatial_aggregation.

#'@example
# scorecard_table <- SC_create_table(aggregated_metrics,
#                                    system.name = list('ECMWF System 5','DWD System 21'),
#                                    reference.name = 'ERA5',
#                                    start.year = 1993,
#                                    end.year = 2016,
#                                    var.name = 'tas', 
#                                    var.unit = 'K',
#                                    table.column.header
#                                    )

test <- SC_create_table(aggregated_metrics)
SC_create_table <- function(aggregated_metrics) {
  
  # For now only for single type scorecards
  
  ## Checks to apply:
  
    # first dimension in aggregated_metrics is system and second dimension is reference
    # to allow 1 region - if region = 1 --> only scorecards 1 & 3 need to be plotted
  
  
    file_metric <- attributes(aggregated_metrics)$metrics
    # start.months <- attributes(transformed_data)$start.months
    # regions <- attributes(transformed_data)$regions    
    # 
    # n.start.months <- dim(transformed_metrics)["sdate"]
    # n.ftime.months <- dim(transformed_metrics)["time"]
    # n.metrics <- dim(transformed_metrics)["metric"]
    # n.regions <- dim(transformed_metrics)["region"]
    
    ### TO DO: ###
    ## Round the metrics

  


    ############### Need to redo function for new data format ##################
    transformed_metrics <- SC_transform_data(aggregated_metrics)
   
    ## Transform or reorder if needed   
    table_to_plot <- list()
     for (sys in 1:dim(aggregated_metrics)['system']) {
      table_by_sys <- list()
      for (ref in 1:dim(aggregated_metrics)['reference']) {
        table_by_ref <- list()
        
        ## Scorecard_type 1: 
        ## (no transformation or reorder)
        table_by_ref$SC1 <- aggregated_metrics[sys, ref,,,,]
        attributes(table_by_ref$SC1) <- attributes(aggregated_metrics) 
        SC_plot_simple_odd(table_by_ref$SC1, title =, subtitle, )
        
        ## Scorecard_type 2: 
        ## (reorder only)
        if (dim(aggregated_metrics)['region'] > 1) {
          new_order <- c(2,1,3,4) ## TO DO: reorder by dimension name not number
          table_by_ref$SC2 <- Reorder(aggregated_metrics[sys, ref,,,,], new_order)  
          SC_plot_simple_even(table_by_ref$SC2, title = , subtitle)
        }
        
        ## Scorecard_type 3: 
        ## (transformation only)
        table_by_ref$SC3 <- transformed_metrics[sys, ref,,,,]
        Plot_SC_odd
        
        ## Scorecard_type 4: 
        ## (transformation and reorder)
        if (dim(aggregated_metrics)['region'] > 1) {
          new_order <- c(2,1,3,4) ## TO DO: reorder by dimension name not number
          table_by_ref$SC4 <- Reorder(transformed_metrics[sys, ref,,,,], new_order)  
        }
        
        ## Calculate color bar breaks for metric mean bias
        if ('mean_bias' %in% file_metric) {
          pos_bias <- which(file_metric == 'mean_bias')
          brks_seq <- SC_breaks(Subset(aggregated_metrics[sys, ref,,,,], along = 'metric', 
                                     indices = pos_bias))
          table_by_ref$brks <- brks_seq
        }
        ## Save data by reference
        table_by_sys <- append(table_by_sys, list(table_by_ref))
        names(table_by_sys)[[length(table_by_sys)]] <- attributes(aggregated_metrics)$reference_names[ref]
      }
      ## Save data by system
      table_to_plot <- append(table_to_plot, list(table_by_sys))
      names(table_to_plot)[[length(table_to_plot)]] <- attributes(aggregated_metrics)$systems_names[sys]
    }
    return(table_to_plot)
}        
    
    

 